`ensembleForecasts` <-
function (x) 
UseMethod("ensembleForecasts")

